==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Repository/src/com/clustercontrol/repository/view/NodeScopeView.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.view;

import java.util.ArrayList;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;

import com.clustercontrol.bean.TableColumnInfo;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.repository.RepositoryPlugin;
import com.clustercontrol.repository.composite.NodeListComposite;
import com.clustercontrol.repository.composite.NodeScopeComposite;
import com.clustercontrol.view.CommonViewPart;

/**
 * Ρɤγץӥ塼饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class NodeScopeView extends CommonViewPart {
    public static final String ID = "com.clustercontrol.repository.view.NodeScopeView";

    // ----- instance ե ----- //

    /** ݥå */
    private NodeScopeComposite composite = null;

    // ----- 󥹥ȥ饯 ----- //

    // ----- instance ᥽å ----- //

    /**
     * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
     */
    public void createPartControl(Composite parent) {
        GridLayout layout = new GridLayout(1, true);
        parent.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        this.composite = new NodeScopeComposite(parent, SWT.NONE);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        composite.setLayoutData(gridData);

        this.update();
    }

    /**
     * Ρɰˤ򤵤ƤΡɤƤɽޤ
     */
    public void update() {
        IWorkbench workbench = RepositoryPlugin.getDefault().getWorkbench();
        IWorkbenchPage page = workbench.getActiveWorkbenchWindow()
                .getActivePage();

        NodeListView view = null;
        if (page != null) {
        	IViewPart viewPart = page.findView(NodeListView.ID);
            view = (NodeListView)viewPart.getAdapter(NodeListView.class);
        }

        String facilityId = null;
        String facilityName = null;
        if (view != null) {
            NodeListComposite composite = view.getComposite();
            CommonTableViewer viewer = composite.getTableViewer();

            StructuredSelection selection = (StructuredSelection) viewer
                    .getSelection();

            ArrayList list = (ArrayList) selection.getFirstElement();
            if (list != null) {
                facilityId = (String) list.get(viewer
                        .getTableColumnIndex(TableColumnInfo.FACILITY_ID));
                facilityName = (String) list.get(viewer
                        .getTableColumnIndex(TableColumnInfo.FACILITY_NAME));
            }
        }

        this.composite.update(facilityId, facilityName);
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Repository/src/com/clustercontrol/repository/view/NodeScopeView.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.view;

import java.util.ArrayList;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;

import com.clustercontrol.bean.TableColumnInfo;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.repository.RepositoryPlugin;
import com.clustercontrol.repository.composite.NodeListComposite;
import com.clustercontrol.repository.composite.NodeScopeComposite;
import com.clustercontrol.view.CommonViewPart;

/**
 * ノードの割当スコープビュークラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class NodeScopeView extends CommonViewPart {
    public static final String ID = "com.clustercontrol.repository.view.NodeScopeView";

    // ----- instance フィールド ----- //

    /** コンポジット */
    private NodeScopeComposite composite = null;

    // ----- コンストラクタ ----- //

    // ----- instance メソッド ----- //

    /**
     * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
     */
    public void createPartControl(Composite parent) {
        GridLayout layout = new GridLayout(1, true);
        parent.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        this.composite = new NodeScopeComposite(parent, SWT.NONE);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        composite.setLayoutData(gridData);

        this.update();
    }

    /**
     * ノード一覧にて選択されているノードの内容を表示します。
     */
    public void update() {
        IWorkbench workbench = RepositoryPlugin.getDefault().getWorkbench();
        IWorkbenchPage page = workbench.getActiveWorkbenchWindow()
                .getActivePage();

        NodeListView view = null;
        if (page != null) {
        	IViewPart viewPart = page.findView(NodeListView.ID);
            view = (NodeListView)viewPart.getAdapter(NodeListView.class);
        }

        String facilityId = null;
        String facilityName = null;
        if (view != null) {
            NodeListComposite composite = view.getComposite();
            CommonTableViewer viewer = composite.getTableViewer();

            StructuredSelection selection = (StructuredSelection) viewer
                    .getSelection();

            ArrayList list = (ArrayList) selection.getFirstElement();
            if (list != null) {
                facilityId = (String) list.get(viewer
                        .getTableColumnIndex(TableColumnInfo.FACILITY_ID));
                facilityName = (String) list.get(viewer
                        .getTableColumnIndex(TableColumnInfo.FACILITY_NAME));
            }
        }

        this.composite.update(facilityId, facilityName);
    }
}
